@@ -13,7 +13,7 @@ int peek() {
  return c;
 }
 
-main() {
+int main() {
  int c;
  int incomment = 0;
  long sloc = 0;
@@ -31,5 +31,6 @@ main() {
     if ((c == '\n') && nonspace) {sloc++;}
  }
  printf("%ld\n", sloc);
+ return 0; /* Report success. */
 }
 
